==> coretoppings-4.0.0.tar.gz: coretoppings-v4.0.0/README.md <==
# CoreToppings
Additional features, plugins, widgets etc for CuboCore Application Suite.

### Installation path
* CoreAction widgets - usr/lib/coreapps/plugins
* ShareIT plugins    - usr/lib/coreapps/shareit

### Download
You can download latest release.
* [Source](https://gitlab.com/cubocore/coretoppings/tags)
* [ArchPackages](https://gitlab.com/cubocore/wiki/tree/master/ArchPackages)

### Dependencies:
* qt5-base
* qt5-location
* qt5-x11extras
* qt5-connectivity
* libpulse
* [libcprime](https://gitlab.com/cubocore/libcprime)

### Dependencies for media
for x11

* ffmpeg - screen/audio capture/recording
* v4l-utils - for webcam

for wayland (optional)

* grim - for screencapture
* wf-recorder - for screen recording

### Dependencies for media control
* playerctl

### Dependencies for rotation
* xorg-xrandr
* iio-sensor-proxy (optional) – for autorotation
* inotify-tools (optional) – for autorotation 

### Dependencies for networking switch
* bluez-utils - for bluetoothctl
* linux-utils - for rfkill
* networkmanager or connman - for wifi and hotspot

### Dependencies for qwickaccess
* redshift - for nightmode
* xorg-xinput - for disabling touchpad/touchscreen/keyboard etc.
* grep
* gawk
* polkit - for elevated privilage
* libnotify - for notifications

### Dependencies for leave
* systemd (optional)
* xdg-utils - for lockscreen

### Information
Please see the Wiki page for this info.[Wiki page](https://gitlab.com/cubocore/wiki) .
* Changes in latest release
* Build from the source
* Tested In
* Known Bugs
* Help Us

### Feedback
* We need your feedback to improve the CoreApps.Send us your feedback through GitLab [issues](https://gitlab.com/groups/cubocore/-/issues).

==> coretoppings-4.1.0.tar.gz: coretoppings-v4.1.0/README.md <==
# CoreToppings
Additional features, plugins, widgets etc for CuboCore Application Suite.

### Installation path
* CoreAction widgets - usr/lib/coreapps/plugins
* ShareIT plugins    - usr/lib/coreapps/shareit

### Download
You can download latest release.
* [Source](https://gitlab.com/cubocore/coretoppings/tags)
* [ArchPackages](https://gitlab.com/cubocore/wiki/tree/master/ArchPackages)

### Dependencies:
* qt5-base
* qt5-x11extras
* qt5-connectivity
* libpulse
* libdbusmenu-qt5
* [libcprime](https://gitlab.com/cubocore/libcprime)

### Dependencies for media
#### For X11

* ffmpeg - screen/audio capture/recording
* v4l-utils - for webcam

#### For wayland (optional)

* grim - for screencapture
* wf-recorder - for screen recording

### Dependencies for media control
* playerctl

### Dependencies for rotation
* xorg-xrandr
* iio-sensor-proxy (optional) – for autorotation
* inotify-tools (optional) – for autorotation 

### Dependencies for networking switch
* bluez-utils - for bluetoothctl
* linux-utils - for rfkill
* networkmanager or connman - for wifi and hotspot

### Dependencies for qwickaccess
* redshift - for nightmode
* xorg-xinput - for disabling touchpad/touchscreen/keyboard etc.
* grep
* gawk
* polkit - for elevated privilage
* libnotify - for notifications

### Dependencies for leave
* systemd (optional)
* xdg-utils - for lockscreen

### Information
Please see the Wiki page for this info.[Wiki page](https://gitlab.com/cubocore/wiki) .
* Changes in latest release
* Build from the source
* Tested In
* Known Bugs
* Help Us

### Feedback
* We need your feedback to improve the CoreApps.Send us your feedback through GitLab [issues](https://gitlab.com/groups/cubocore/-/issues).
